@@ -24,12 +24,10 @@
 #define PLATE_ROWS    5
 #define PLATE_COLUMNS 5
 
-static Control::Prefs *prefs=new Control::Prefs(L"Control");
-
 Control::Control()
  : showAll(false)
 {
-  SetPrefs(::prefs);
+  // no code
 }
 
 Control::~Control()
